@@ -33,7 +33,8 @@ int count,k;
 
 int get_nearests(double x1, double x2, double cell, double rcut){
     // Return ABS(axis distances)
-    dx = x2-x1;
+    dx = fabs(x2-x1);
+
     count = dx / cell;
     dx = dx - count * cell;
     if (fabs(dx-cell) < fabs(dx)){
@@ -50,9 +51,11 @@ int get_nearests(double x1, double x2, double cell, double rcut){
         x_list[x_list_id]=fabs(dx);
         x_list_id++;
     }   
-    dx = x_list[x_list_0];
+
+    dx = x_list[x_list_0]-cell;
     while (dx > -rcut){
         if (x_list_id-x_list_0 >= MAX_X_LIST){
+            printf("exit -1 dx > -rcut");
             exit(-1);
         }
         dx -= cell;
@@ -79,7 +82,7 @@ int get_distances(double * r1, double * r2, double cell, double rcut){
                     for (int k=0; k<MAX_X_LIST; k++)
                         if (x_list[k+2*MAX_X_LIST]>=0){
                             l_list_buf = sqrt(pow(x_list[i],2) + pow(x_list[j+MAX_X_LIST],2) + pow(x_list[k+2*MAX_X_LIST],2));
-                            if (l_list_buf>0.1 && l_list_buf < rcut){
+                            if (l_list_buf>0 && l_list_buf < rcut){
                                 l_list[l_list_id]=l_list_buf;
                                 l_list_id++;
                             }
@@ -93,33 +96,26 @@ int get_distances(double * r1, double * r2, double cell, double rcut){
 
 int rdf(int nbins, double rcut, double * g_r, int Npart1, int Npart2, int Nsteps, double * Rpart1, double * Rpart2, double cell){
     double rho = Npart2/(cell*cell*cell);
-    double r_list[Npart1*Npart2*Nsteps];
-    int r_list_id=0;
-    for (int step=0; step < Nsteps; step++)
-        for (int i=0; i < Npart1; i++)
-            for (int j=0; j<Npart2; j++){
-                get_distances(&Rpart1[3*Npart1*step+i*3], &Rpart2[3*Npart2*step+j*3],cell, rcut);
-                for (int k=0; k<MAX_L_LIST; k++)
-                    if (l_list[k] > 0 ){
-                        r_list[r_list_id] = l_list[k];
-                        r_list_id++;
-                    }
-            }
-    
-    double dbins=rcut/nbins;
     int counts[nbins];
     for (int i=0; i<nbins; i++){
         counts[i] = 0;
     }
-    for (int i=0; i<r_list_id; i++){
-        if ((r_list[i]>0) && (r_list[i]<rcut)){
-            counts[(int)(r_list[i]/dbins)] += 1;
-        }
-    }
+    double dbins=rcut/nbins;
+    for (int step=0; step < Nsteps; step++)
+        for (int i=0; i < Npart1; i++)
+            for (int j=0; j<Npart2; j++){
+                get_distances(&Rpart1[3*Npart1*step+i*3], &Rpart2[3*Npart2*step+j*3],cell, rcut);
 
-//     double *g_r = malloc(nbins);
+                for (int k=0; k<MAX_L_LIST; k++)
+                    if (l_list[k] > 0 && l_list[k] < rcut ){
+                        counts[(int)(l_list[k]/dbins)]++;
+                    }
+            }
+    
+    
     for (int i=0; i<nbins; i++){
         g_r[i] = ( counts[i]/(4*3.14*(pow(dbins*(i+0.5),2)*dbins)) / Npart1/Nsteps) / rho;
     }
+
     return 0;
 }
\ No newline at end of file
